# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/choreography_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/choreography_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#cyber/proto/choreography_conf.proto\x12\x12\x61pollo.cyber.proto\"D\n\x10\x43horeographyTask\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\x05\x12\x0f\n\x04prio\x18\x03 \x01(\r:\x01\x31\"\xf7\x02\n\x10\x43horeographyConf\x12\"\n\x1a\x63horeography_processor_num\x18\x01 \x01(\r\x12\x1d\n\x15\x63horeography_affinity\x18\x02 \x01(\t\x12%\n\x1d\x63horeography_processor_policy\x18\x03 \x01(\t\x12#\n\x1b\x63horeography_processor_prio\x18\x04 \x01(\x05\x12\x1b\n\x13\x63horeography_cpuset\x18\x05 \x01(\t\x12\x1a\n\x12pool_processor_num\x18\x06 \x01(\r\x12\x15\n\rpool_affinity\x18\x07 \x01(\t\x12\x1d\n\x15pool_processor_policy\x18\x08 \x01(\t\x12\x1b\n\x13pool_processor_prio\x18\t \x01(\x05\x12\x13\n\x0bpool_cpuset\x18\n \x01(\t\x12\x33\n\x05tasks\x18\x0b \x03(\x0b\x32$.apollo.cyber.proto.ChoreographyTask'
)




_CHOREOGRAPHYTASK = _descriptor.Descriptor(
  name='ChoreographyTask',
  full_name='apollo.cyber.proto.ChoreographyTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.ChoreographyTask.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processor', full_name='apollo.cyber.proto.ChoreographyTask.processor', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prio', full_name='apollo.cyber.proto.ChoreographyTask.prio', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=127,
)


_CHOREOGRAPHYCONF = _descriptor.Descriptor(
  name='ChoreographyConf',
  full_name='apollo.cyber.proto.ChoreographyConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choreography_processor_num', full_name='apollo.cyber.proto.ChoreographyConf.choreography_processor_num', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choreography_affinity', full_name='apollo.cyber.proto.ChoreographyConf.choreography_affinity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choreography_processor_policy', full_name='apollo.cyber.proto.ChoreographyConf.choreography_processor_policy', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choreography_processor_prio', full_name='apollo.cyber.proto.ChoreographyConf.choreography_processor_prio', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choreography_cpuset', full_name='apollo.cyber.proto.ChoreographyConf.choreography_cpuset', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_processor_num', full_name='apollo.cyber.proto.ChoreographyConf.pool_processor_num', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_affinity', full_name='apollo.cyber.proto.ChoreographyConf.pool_affinity', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_processor_policy', full_name='apollo.cyber.proto.ChoreographyConf.pool_processor_policy', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_processor_prio', full_name='apollo.cyber.proto.ChoreographyConf.pool_processor_prio', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_cpuset', full_name='apollo.cyber.proto.ChoreographyConf.pool_cpuset', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='apollo.cyber.proto.ChoreographyConf.tasks', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=505,
)

_CHOREOGRAPHYCONF.fields_by_name['tasks'].message_type = _CHOREOGRAPHYTASK
DESCRIPTOR.message_types_by_name['ChoreographyTask'] = _CHOREOGRAPHYTASK
DESCRIPTOR.message_types_by_name['ChoreographyConf'] = _CHOREOGRAPHYCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChoreographyTask = _reflection.GeneratedProtocolMessageType('ChoreographyTask', (_message.Message,), {
  'DESCRIPTOR' : _CHOREOGRAPHYTASK,
  '__module__' : 'cyber.proto.choreography_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ChoreographyTask)
  })
_sym_db.RegisterMessage(ChoreographyTask)

ChoreographyConf = _reflection.GeneratedProtocolMessageType('ChoreographyConf', (_message.Message,), {
  'DESCRIPTOR' : _CHOREOGRAPHYCONF,
  '__module__' : 'cyber.proto.choreography_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ChoreographyConf)
  })
_sym_db.RegisterMessage(ChoreographyConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/gnss/proto/gnss.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/gnss/proto/gnss.proto',
  package='apollo.drivers.gnss',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/drivers/gnss/proto/gnss.proto\x12\x13\x61pollo.drivers.gnss\x1a!modules/common/proto/header.proto\x1a#modules/common/proto/geometry.proto\"\x82\x04\n\x04Gnss\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x18\n\x10measurement_time\x18\x02 \x01(\x01\x12\x1b\n\x10velocity_latency\x18\x03 \x01(\x02:\x01\x30\x12)\n\x08position\x18\x04 \x01(\x0b\x32\x17.apollo.common.PointLLH\x12\x30\n\x10position_std_dev\x18\x05 \x01(\x0b\x32\x16.apollo.common.Point3D\x12/\n\x0flinear_velocity\x18\x06 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x37\n\x17linear_velocity_std_dev\x18\x07 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x10\n\x08num_sats\x18\x08 \x01(\x05\x12,\n\x04type\x18\t \x01(\x0e\x32\x1e.apollo.drivers.gnss.Gnss.Type\x12\x17\n\x0fsolution_status\x18\n \x01(\r\x12\x15\n\rposition_type\x18\x0b \x01(\r\"e\n\x04Type\x12\x0b\n\x07INVALID\x10\x00\x12\x0e\n\nPROPAGATED\x10\x01\x12\n\n\x06SINGLE\x10\x02\x12\x0b\n\x07PSRDIFF\x10\x03\x12\x07\n\x03PPP\x10\x04\x12\r\n\tRTK_FLOAT\x10\x05\x12\x0f\n\x0bRTK_INTEGER\x10\x06\">\n\x07RawData\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])



_GNSS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.drivers.gnss.Gnss.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPAGATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINGLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PSRDIFF', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PPP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTK_FLOAT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTK_INTEGER', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=548,
  serialized_end=649,
)
_sym_db.RegisterEnumDescriptor(_GNSS_TYPE)


_GNSS = _descriptor.Descriptor(
  name='Gnss',
  full_name='apollo.drivers.gnss.Gnss',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.gnss.Gnss.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_time', full_name='apollo.drivers.gnss.Gnss.measurement_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_latency', full_name='apollo.drivers.gnss.Gnss.velocity_latency', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.drivers.gnss.Gnss.position', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_std_dev', full_name='apollo.drivers.gnss.Gnss.position_std_dev', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity', full_name='apollo.drivers.gnss.Gnss.linear_velocity', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity_std_dev', full_name='apollo.drivers.gnss.Gnss.linear_velocity_std_dev', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_sats', full_name='apollo.drivers.gnss.Gnss.num_sats', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.drivers.gnss.Gnss.type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solution_status', full_name='apollo.drivers.gnss.Gnss.solution_status', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_type', full_name='apollo.drivers.gnss.Gnss.position_type', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GNSS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=649,
)


_RAWDATA = _descriptor.Descriptor(
  name='RawData',
  full_name='apollo.drivers.gnss.RawData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.gnss.RawData.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='apollo.drivers.gnss.RawData.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=713,
)

_GNSS.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_GNSS.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTLLH
_GNSS.fields_by_name['position_std_dev'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_GNSS.fields_by_name['linear_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_GNSS.fields_by_name['linear_velocity_std_dev'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_GNSS.fields_by_name['type'].enum_type = _GNSS_TYPE
_GNSS_TYPE.containing_type = _GNSS
_RAWDATA.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
DESCRIPTOR.message_types_by_name['Gnss'] = _GNSS
DESCRIPTOR.message_types_by_name['RawData'] = _RAWDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Gnss = _reflection.GeneratedProtocolMessageType('Gnss', (_message.Message,), {
  'DESCRIPTOR' : _GNSS,
  '__module__' : 'modules.drivers.gnss.proto.gnss_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.Gnss)
  })
_sym_db.RegisterMessage(Gnss)

RawData = _reflection.GeneratedProtocolMessageType('RawData', (_message.Message,), {
  'DESCRIPTOR' : _RAWDATA,
  '__module__' : 'modules.drivers.gnss.proto.gnss_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.RawData)
  })
_sym_db.RegisterMessage(RawData)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/auto_tuning_model_input.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/auto_tuning_model_input.proto',
  package='apollo.planning.autotuning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4modules/planning/proto/auto_tuning_model_input.proto\x12\x1a\x61pollo.planning.autotuning\"\xf9\x04\n\x14PathPointwiseFeature\x12\t\n\x01l\x18\x01 \x01(\x01\x12\n\n\x02\x64l\x18\x02 \x01(\x01\x12\x0b\n\x03\x64\x64l\x18\x03 \x01(\x01\x12\r\n\x05kappa\x18\x04 \x01(\x01\x12W\n\robstacle_info\x18\x05 \x03(\x0b\x32@.apollo.planning.autotuning.PathPointwiseFeature.ObstacleFeature\x12`\n\x12left_bound_feature\x18\x06 \x01(\x0b\x32\x44.apollo.planning.autotuning.PathPointwiseFeature.BoundRelatedFeature\x12\x61\n\x13right_bound_feature\x18\x07 \x01(\x0b\x32\x44.apollo.planning.autotuning.PathPointwiseFeature.BoundRelatedFeature\x1a+\n\x0fObstacleFeature\x12\x18\n\x10lateral_distance\x18\x01 \x01(\x01\x1a\xe2\x01\n\x13\x42oundRelatedFeature\x12\x16\n\x0e\x62ound_distance\x18\x01 \x01(\x01\x12l\n\x0f\x63rossable_level\x18\x02 \x01(\x0e\x32S.apollo.planning.autotuning.PathPointwiseFeature.BoundRelatedFeature.CrossableLevel\"E\n\x0e\x43rossableLevel\x12\x0e\n\nCROSS_FREE\x10\x00\x12\x0e\n\nCROSS_ABLE\x10\x01\x12\x13\n\x0f\x43ROSS_FORBIDDEN\x10\x02\"\x87\x08\n\x15SpeedPointwiseFeature\x12\x0c\n\x01s\x18\x01 \x01(\x01:\x01\x30\x12\x0c\n\x01t\x18\x02 \x01(\x01:\x01\x30\x12\x0c\n\x01v\x18\x03 \x01(\x01:\x01\x30\x12\x16\n\x0bspeed_limit\x18\x04 \x01(\x01:\x01\x30\x12\x0e\n\x03\x61\x63\x63\x18\x05 \x01(\x01:\x01\x30\x12\x0f\n\x04jerk\x18\x06 \x01(\x01:\x01\x30\x12]\n\x12\x66ollow_obs_feature\x18\x07 \x03(\x0b\x32\x41.apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature\x12_\n\x14overtake_obs_feature\x18\x08 \x03(\x0b\x32\x41.apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature\x12\\\n\x11nudge_obs_feature\x18\t \x03(\x0b\x32\x41.apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature\x12[\n\x10stop_obs_feature\x18\n \x03(\x0b\x32\x41.apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature\x12\x1a\n\x0f\x63ollision_times\x18\x0b \x01(\x05:\x01\x30\x12^\n\x13virtual_obs_feature\x18\x0c \x03(\x0b\x32\x41.apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature\x12\x16\n\x0blateral_acc\x18\r \x01(\x01:\x01\x30\x12\x1d\n\x12path_curvature_abs\x18\x0e \x01(\x01:\x01\x30\x12\x65\n\x1asidepass_front_obs_feature\x18\x0f \x03(\x0b\x32\x41.apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature\x12\x64\n\x19sidepass_rear_obs_feature\x18\x10 \x03(\x0b\x32\x41.apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature\x1a\x8f\x01\n\x0fObstacleFeature\x12\x1d\n\x15longitudinal_distance\x18\x01 \x01(\x01\x12\x16\n\x0eobstacle_speed\x18\x02 \x01(\x01\x12\x1c\n\x10lateral_distance\x18\x03 \x01(\x01:\x02\x31\x30\x12\x13\n\x0bprobability\x18\x04 \x01(\x01\x12\x12\n\nrelative_v\x18\x05 \x01(\x01\"\xba\x01\n\x1aTrajectoryPointwiseFeature\x12L\n\x12path_input_feature\x18\x01 \x01(\x0b\x32\x30.apollo.planning.autotuning.PathPointwiseFeature\x12N\n\x13speed_input_feature\x18\x02 \x01(\x0b\x32\x31.apollo.planning.autotuning.SpeedPointwiseFeature\"b\n\x11TrajectoryFeature\x12M\n\rpoint_feature\x18\x01 \x03(\x0b\x32\x36.apollo.planning.autotuning.TrajectoryPointwiseFeature'
)



_PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE_CROSSABLELEVEL = _descriptor.EnumDescriptor(
  name='CrossableLevel',
  full_name='apollo.planning.autotuning.PathPointwiseFeature.BoundRelatedFeature.CrossableLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CROSS_FREE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CROSS_ABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CROSS_FORBIDDEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=649,
  serialized_end=718,
)
_sym_db.RegisterEnumDescriptor(_PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE_CROSSABLELEVEL)


_PATHPOINTWISEFEATURE_OBSTACLEFEATURE = _descriptor.Descriptor(
  name='ObstacleFeature',
  full_name='apollo.planning.autotuning.PathPointwiseFeature.ObstacleFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lateral_distance', full_name='apollo.planning.autotuning.PathPointwiseFeature.ObstacleFeature.lateral_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=489,
)

_PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE = _descriptor.Descriptor(
  name='BoundRelatedFeature',
  full_name='apollo.planning.autotuning.PathPointwiseFeature.BoundRelatedFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bound_distance', full_name='apollo.planning.autotuning.PathPointwiseFeature.BoundRelatedFeature.bound_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crossable_level', full_name='apollo.planning.autotuning.PathPointwiseFeature.BoundRelatedFeature.crossable_level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE_CROSSABLELEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=492,
  serialized_end=718,
)

_PATHPOINTWISEFEATURE = _descriptor.Descriptor(
  name='PathPointwiseFeature',
  full_name='apollo.planning.autotuning.PathPointwiseFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='l', full_name='apollo.planning.autotuning.PathPointwiseFeature.l', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dl', full_name='apollo.planning.autotuning.PathPointwiseFeature.dl', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ddl', full_name='apollo.planning.autotuning.PathPointwiseFeature.ddl', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa', full_name='apollo.planning.autotuning.PathPointwiseFeature.kappa', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_info', full_name='apollo.planning.autotuning.PathPointwiseFeature.obstacle_info', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_bound_feature', full_name='apollo.planning.autotuning.PathPointwiseFeature.left_bound_feature', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_bound_feature', full_name='apollo.planning.autotuning.PathPointwiseFeature.right_bound_feature', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PATHPOINTWISEFEATURE_OBSTACLEFEATURE, _PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=718,
)


_SPEEDPOINTWISEFEATURE_OBSTACLEFEATURE = _descriptor.Descriptor(
  name='ObstacleFeature',
  full_name='apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='longitudinal_distance', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature.longitudinal_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_speed', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature.obstacle_speed', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_distance', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature.lateral_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='probability', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature.probability', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_v', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature.relative_v', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1609,
  serialized_end=1752,
)

_SPEEDPOINTWISEFEATURE = _descriptor.Descriptor(
  name='SpeedPointwiseFeature',
  full_name='apollo.planning.autotuning.SpeedPointwiseFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.t', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.v', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.speed_limit', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.acc', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.jerk', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='follow_obs_feature', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.follow_obs_feature', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overtake_obs_feature', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.overtake_obs_feature', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nudge_obs_feature', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.nudge_obs_feature', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_obs_feature', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.stop_obs_feature', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collision_times', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.collision_times', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_obs_feature', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.virtual_obs_feature', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_acc', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.lateral_acc', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_curvature_abs', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.path_curvature_abs', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sidepass_front_obs_feature', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.sidepass_front_obs_feature', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sidepass_rear_obs_feature', full_name='apollo.planning.autotuning.SpeedPointwiseFeature.sidepass_rear_obs_feature', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SPEEDPOINTWISEFEATURE_OBSTACLEFEATURE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=721,
  serialized_end=1752,
)


_TRAJECTORYPOINTWISEFEATURE = _descriptor.Descriptor(
  name='TrajectoryPointwiseFeature',
  full_name='apollo.planning.autotuning.TrajectoryPointwiseFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_input_feature', full_name='apollo.planning.autotuning.TrajectoryPointwiseFeature.path_input_feature', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_input_feature', full_name='apollo.planning.autotuning.TrajectoryPointwiseFeature.speed_input_feature', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1755,
  serialized_end=1941,
)


_TRAJECTORYFEATURE = _descriptor.Descriptor(
  name='TrajectoryFeature',
  full_name='apollo.planning.autotuning.TrajectoryFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='point_feature', full_name='apollo.planning.autotuning.TrajectoryFeature.point_feature', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1943,
  serialized_end=2041,
)

_PATHPOINTWISEFEATURE_OBSTACLEFEATURE.containing_type = _PATHPOINTWISEFEATURE
_PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE.fields_by_name['crossable_level'].enum_type = _PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE_CROSSABLELEVEL
_PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE.containing_type = _PATHPOINTWISEFEATURE
_PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE_CROSSABLELEVEL.containing_type = _PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE
_PATHPOINTWISEFEATURE.fields_by_name['obstacle_info'].message_type = _PATHPOINTWISEFEATURE_OBSTACLEFEATURE
_PATHPOINTWISEFEATURE.fields_by_name['left_bound_feature'].message_type = _PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE
_PATHPOINTWISEFEATURE.fields_by_name['right_bound_feature'].message_type = _PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE
_SPEEDPOINTWISEFEATURE_OBSTACLEFEATURE.containing_type = _SPEEDPOINTWISEFEATURE
_SPEEDPOINTWISEFEATURE.fields_by_name['follow_obs_feature'].message_type = _SPEEDPOINTWISEFEATURE_OBSTACLEFEATURE
_SPEEDPOINTWISEFEATURE.fields_by_name['overtake_obs_feature'].message_type = _SPEEDPOINTWISEFEATURE_OBSTACLEFEATURE
_SPEEDPOINTWISEFEATURE.fields_by_name['nudge_obs_feature'].message_type = _SPEEDPOINTWISEFEATURE_OBSTACLEFEATURE
_SPEEDPOINTWISEFEATURE.fields_by_name['stop_obs_feature'].message_type = _SPEEDPOINTWISEFEATURE_OBSTACLEFEATURE
_SPEEDPOINTWISEFEATURE.fields_by_name['virtual_obs_feature'].message_type = _SPEEDPOINTWISEFEATURE_OBSTACLEFEATURE
_SPEEDPOINTWISEFEATURE.fields_by_name['sidepass_front_obs_feature'].message_type = _SPEEDPOINTWISEFEATURE_OBSTACLEFEATURE
_SPEEDPOINTWISEFEATURE.fields_by_name['sidepass_rear_obs_feature'].message_type = _SPEEDPOINTWISEFEATURE_OBSTACLEFEATURE
_TRAJECTORYPOINTWISEFEATURE.fields_by_name['path_input_feature'].message_type = _PATHPOINTWISEFEATURE
_TRAJECTORYPOINTWISEFEATURE.fields_by_name['speed_input_feature'].message_type = _SPEEDPOINTWISEFEATURE
_TRAJECTORYFEATURE.fields_by_name['point_feature'].message_type = _TRAJECTORYPOINTWISEFEATURE
DESCRIPTOR.message_types_by_name['PathPointwiseFeature'] = _PATHPOINTWISEFEATURE
DESCRIPTOR.message_types_by_name['SpeedPointwiseFeature'] = _SPEEDPOINTWISEFEATURE
DESCRIPTOR.message_types_by_name['TrajectoryPointwiseFeature'] = _TRAJECTORYPOINTWISEFEATURE
DESCRIPTOR.message_types_by_name['TrajectoryFeature'] = _TRAJECTORYFEATURE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PathPointwiseFeature = _reflection.GeneratedProtocolMessageType('PathPointwiseFeature', (_message.Message,), {

  'ObstacleFeature' : _reflection.GeneratedProtocolMessageType('ObstacleFeature', (_message.Message,), {
    'DESCRIPTOR' : _PATHPOINTWISEFEATURE_OBSTACLEFEATURE,
    '__module__' : 'modules.planning.proto.auto_tuning_model_input_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.PathPointwiseFeature.ObstacleFeature)
    })
  ,

  'BoundRelatedFeature' : _reflection.GeneratedProtocolMessageType('BoundRelatedFeature', (_message.Message,), {
    'DESCRIPTOR' : _PATHPOINTWISEFEATURE_BOUNDRELATEDFEATURE,
    '__module__' : 'modules.planning.proto.auto_tuning_model_input_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.PathPointwiseFeature.BoundRelatedFeature)
    })
  ,
  'DESCRIPTOR' : _PATHPOINTWISEFEATURE,
  '__module__' : 'modules.planning.proto.auto_tuning_model_input_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.PathPointwiseFeature)
  })
_sym_db.RegisterMessage(PathPointwiseFeature)
_sym_db.RegisterMessage(PathPointwiseFeature.ObstacleFeature)
_sym_db.RegisterMessage(PathPointwiseFeature.BoundRelatedFeature)

SpeedPointwiseFeature = _reflection.GeneratedProtocolMessageType('SpeedPointwiseFeature', (_message.Message,), {

  'ObstacleFeature' : _reflection.GeneratedProtocolMessageType('ObstacleFeature', (_message.Message,), {
    'DESCRIPTOR' : _SPEEDPOINTWISEFEATURE_OBSTACLEFEATURE,
    '__module__' : 'modules.planning.proto.auto_tuning_model_input_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.SpeedPointwiseFeature.ObstacleFeature)
    })
  ,
  'DESCRIPTOR' : _SPEEDPOINTWISEFEATURE,
  '__module__' : 'modules.planning.proto.auto_tuning_model_input_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.SpeedPointwiseFeature)
  })
_sym_db.RegisterMessage(SpeedPointwiseFeature)
_sym_db.RegisterMessage(SpeedPointwiseFeature.ObstacleFeature)

TrajectoryPointwiseFeature = _reflection.GeneratedProtocolMessageType('TrajectoryPointwiseFeature', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORYPOINTWISEFEATURE,
  '__module__' : 'modules.planning.proto.auto_tuning_model_input_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.TrajectoryPointwiseFeature)
  })
_sym_db.RegisterMessage(TrajectoryPointwiseFeature)

TrajectoryFeature = _reflection.GeneratedProtocolMessageType('TrajectoryFeature', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORYFEATURE,
  '__module__' : 'modules.planning.proto.auto_tuning_model_input_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.TrajectoryFeature)
  })
_sym_db.RegisterMessage(TrajectoryFeature)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/task_manager/proto/task_manager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.routing.proto import routing_pb2 as modules_dot_routing_dot_proto_dot_routing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/task_manager/proto/task_manager.proto',
  package='apollo.task_manager',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-modules/task_manager/proto/task_manager.proto\x12\x13\x61pollo.task_manager\x1a!modules/common/proto/header.proto\x1a#modules/routing/proto/routing.proto\"^\n\x10\x43ycleRoutingTask\x12\x11\n\tcycle_num\x18\x01 \x01(\x05\x12\x37\n\x0frouting_request\x18\x02 \x01(\x0b\x32\x1e.apollo.routing.RoutingRequest\"\xb5\x01\n\x04Task\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x11\n\ttask_name\x18\x02 \x01(\t\x12\x30\n\ttask_type\x18\x03 \x01(\x0e\x32\x1d.apollo.task_manager.TaskType\x12\x41\n\x12\x63ycle_routing_task\x18\x04 \x01(\x0b\x32%.apollo.task_manager.CycleRoutingTask*\x1d\n\x08TaskType\x12\x11\n\rCYCLE_ROUTING\x10\x00'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_routing_dot_proto_dot_routing__pb2.DESCRIPTOR,])

_TASKTYPE = _descriptor.EnumDescriptor(
  name='TaskType',
  full_name='apollo.task_manager.TaskType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CYCLE_ROUTING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=422,
  serialized_end=451,
)
_sym_db.RegisterEnumDescriptor(_TASKTYPE)

TaskType = enum_type_wrapper.EnumTypeWrapper(_TASKTYPE)
CYCLE_ROUTING = 0



_CYCLEROUTINGTASK = _descriptor.Descriptor(
  name='CycleRoutingTask',
  full_name='apollo.task_manager.CycleRoutingTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cycle_num', full_name='apollo.task_manager.CycleRoutingTask.cycle_num', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_request', full_name='apollo.task_manager.CycleRoutingTask.routing_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=236,
)


_TASK = _descriptor.Descriptor(
  name='Task',
  full_name='apollo.task_manager.Task',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.task_manager.Task.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_name', full_name='apollo.task_manager.Task.task_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_type', full_name='apollo.task_manager.Task.task_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cycle_routing_task', full_name='apollo.task_manager.Task.cycle_routing_task', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=420,
)

_CYCLEROUTINGTASK.fields_by_name['routing_request'].message_type = modules_dot_routing_dot_proto_dot_routing__pb2._ROUTINGREQUEST
_TASK.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_TASK.fields_by_name['task_type'].enum_type = _TASKTYPE
_TASK.fields_by_name['cycle_routing_task'].message_type = _CYCLEROUTINGTASK
DESCRIPTOR.message_types_by_name['CycleRoutingTask'] = _CYCLEROUTINGTASK
DESCRIPTOR.message_types_by_name['Task'] = _TASK
DESCRIPTOR.enum_types_by_name['TaskType'] = _TASKTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CycleRoutingTask = _reflection.GeneratedProtocolMessageType('CycleRoutingTask', (_message.Message,), {
  'DESCRIPTOR' : _CYCLEROUTINGTASK,
  '__module__' : 'modules.task_manager.proto.task_manager_pb2'
  # @@protoc_insertion_point(class_scope:apollo.task_manager.CycleRoutingTask)
  })
_sym_db.RegisterMessage(CycleRoutingTask)

Task = _reflection.GeneratedProtocolMessageType('Task', (_message.Message,), {
  'DESCRIPTOR' : _TASK,
  '__module__' : 'modules.task_manager.proto.task_manager_pb2'
  # @@protoc_insertion_point(class_scope:apollo.task_manager.Task)
  })
_sym_db.RegisterMessage(Task)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_obstacles.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import error_code_pb2 as modules_dot_common_dot_proto_dot_error__code__pb2
from modules.perception.proto import perception_obstacle_pb2 as modules_dot_perception_dot_proto_dot_perception__obstacle__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_obstacles.proto',
  package='apollo.v2x',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/v2x/proto/v2x_obstacles.proto\x12\napollo.v2x\x1a!modules/common/proto/header.proto\x1a%modules/common/proto/error_code.proto\x1a\x32modules/perception/proto/perception_obstacle.proto\"(\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"\x9f\x01\n\x0bMiniAreaMap\x12\x0f\n\x07rscu_id\x18\x01 \x01(\x0c\x12+\n\x10\x66\x65\x61ture_position\x18\x02 \x01(\x0b\x32\x11.apollo.v2x.Point\x12)\n\x0estart_position\x18\x03 \x01(\x0b\x32\x11.apollo.v2x.Point\x12\'\n\x0c\x65nd_position\x18\x04 \x01(\x0b\x32\x11.apollo.v2x.Point\"E\n\x13\x41\x62normalInformation\x12\x15\n\raverage_speed\x18\x01 \x01(\x01\x12\x17\n\x0fvehicle_density\x18\x02 \x01(\x01\"\xfc\x02\n\x0eV2XInformation\x12\x34\n\x08v2x_type\x18\x01 \x03(\x0e\x32\".apollo.v2x.V2XInformation.V2XType\x12.\n\x13traffic_event_start\x18\x03 \x01(\x0b\x32\x11.apollo.v2x.Point\x12\x34\n\x19traffic_event_start_error\x18\x04 \x01(\x0b\x32\x11.apollo.v2x.Point\x12,\n\x11traffic_event_end\x18\x05 \x01(\x0b\x32\x11.apollo.v2x.Point\x12\x32\n\x17traffic_event_end_error\x18\x06 \x01(\x0b\x32\x11.apollo.v2x.Point\x12\x36\n\rabnormal_info\x18\x07 \x01(\x0b\x32\x1f.apollo.v2x.AbnormalInformation\"4\n\x07V2XType\x12\x08\n\x04NONE\x10\x00\x12\x0f\n\x0bZOMBIES_CAR\x10\x01\x12\x0e\n\nBLIND_ZONE\x10\x02\"\x7f\n\x0bV2XObstacle\x12\x42\n\x13perception_obstacle\x18\x01 \x01(\x0b\x32%.apollo.perception.PerceptionObstacle\x12,\n\x08v2x_info\x18\x02 \x01(\x0b\x32\x1a.apollo.v2x.V2XInformation\"\xd7\x01\n\x0cV2XObstacles\x12-\n\x0cv2x_obstacle\x18\x01 \x03(\x0b\x32\x17.apollo.v2x.V2XObstacle\x12)\n\x08\x61rea_map\x18\x02 \x01(\x0b\x32\x17.apollo.v2x.MiniAreaMap\x12\x14\n\x0ctraffic_flow\x18\x03 \x01(\x01\x12%\n\x06header\x18\x04 \x01(\x0b\x32\x15.apollo.common.Header\x12\x30\n\nerror_code\x18\x05 \x01(\x0e\x32\x18.apollo.common.ErrorCode:\x02OK'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_error__code__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_perception__obstacle__pb2.DESCRIPTOR,])



_V2XINFORMATION_V2XTYPE = _descriptor.EnumDescriptor(
  name='V2XType',
  full_name='apollo.v2x.V2XInformation.V2XType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ZOMBIES_CAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLIND_ZONE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=783,
  serialized_end=835,
)
_sym_db.RegisterEnumDescriptor(_V2XINFORMATION_V2XTYPE)


_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='apollo.v2x.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.v2x.Point.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.v2x.Point.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.v2x.Point.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=219,
)


_MINIAREAMAP = _descriptor.Descriptor(
  name='MiniAreaMap',
  full_name='apollo.v2x.MiniAreaMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rscu_id', full_name='apollo.v2x.MiniAreaMap.rscu_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_position', full_name='apollo.v2x.MiniAreaMap.feature_position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_position', full_name='apollo.v2x.MiniAreaMap.start_position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_position', full_name='apollo.v2x.MiniAreaMap.end_position', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=381,
)


_ABNORMALINFORMATION = _descriptor.Descriptor(
  name='AbnormalInformation',
  full_name='apollo.v2x.AbnormalInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='average_speed', full_name='apollo.v2x.AbnormalInformation.average_speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_density', full_name='apollo.v2x.AbnormalInformation.vehicle_density', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=452,
)


_V2XINFORMATION = _descriptor.Descriptor(
  name='V2XInformation',
  full_name='apollo.v2x.V2XInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='v2x_type', full_name='apollo.v2x.V2XInformation.v2x_type', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_event_start', full_name='apollo.v2x.V2XInformation.traffic_event_start', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_event_start_error', full_name='apollo.v2x.V2XInformation.traffic_event_start_error', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_event_end', full_name='apollo.v2x.V2XInformation.traffic_event_end', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_event_end_error', full_name='apollo.v2x.V2XInformation.traffic_event_end_error', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='abnormal_info', full_name='apollo.v2x.V2XInformation.abnormal_info', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _V2XINFORMATION_V2XTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=835,
)


_V2XOBSTACLE = _descriptor.Descriptor(
  name='V2XObstacle',
  full_name='apollo.v2x.V2XObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='perception_obstacle', full_name='apollo.v2x.V2XObstacle.perception_obstacle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v2x_info', full_name='apollo.v2x.V2XObstacle.v2x_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=837,
  serialized_end=964,
)


_V2XOBSTACLES = _descriptor.Descriptor(
  name='V2XObstacles',
  full_name='apollo.v2x.V2XObstacles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='v2x_obstacle', full_name='apollo.v2x.V2XObstacles.v2x_obstacle', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_map', full_name='apollo.v2x.V2XObstacles.area_map', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_flow', full_name='apollo.v2x.V2XObstacles.traffic_flow', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.v2x.V2XObstacles.header', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_code', full_name='apollo.v2x.V2XObstacles.error_code', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=967,
  serialized_end=1182,
)

_MINIAREAMAP.fields_by_name['feature_position'].message_type = _POINT
_MINIAREAMAP.fields_by_name['start_position'].message_type = _POINT
_MINIAREAMAP.fields_by_name['end_position'].message_type = _POINT
_V2XINFORMATION.fields_by_name['v2x_type'].enum_type = _V2XINFORMATION_V2XTYPE
_V2XINFORMATION.fields_by_name['traffic_event_start'].message_type = _POINT
_V2XINFORMATION.fields_by_name['traffic_event_start_error'].message_type = _POINT
_V2XINFORMATION.fields_by_name['traffic_event_end'].message_type = _POINT
_V2XINFORMATION.fields_by_name['traffic_event_end_error'].message_type = _POINT
_V2XINFORMATION.fields_by_name['abnormal_info'].message_type = _ABNORMALINFORMATION
_V2XINFORMATION_V2XTYPE.containing_type = _V2XINFORMATION
_V2XOBSTACLE.fields_by_name['perception_obstacle'].message_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._PERCEPTIONOBSTACLE
_V2XOBSTACLE.fields_by_name['v2x_info'].message_type = _V2XINFORMATION
_V2XOBSTACLES.fields_by_name['v2x_obstacle'].message_type = _V2XOBSTACLE
_V2XOBSTACLES.fields_by_name['area_map'].message_type = _MINIAREAMAP
_V2XOBSTACLES.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_V2XOBSTACLES.fields_by_name['error_code'].enum_type = modules_dot_common_dot_proto_dot_error__code__pb2._ERRORCODE
DESCRIPTOR.message_types_by_name['Point'] = _POINT
DESCRIPTOR.message_types_by_name['MiniAreaMap'] = _MINIAREAMAP
DESCRIPTOR.message_types_by_name['AbnormalInformation'] = _ABNORMALINFORMATION
DESCRIPTOR.message_types_by_name['V2XInformation'] = _V2XINFORMATION
DESCRIPTOR.message_types_by_name['V2XObstacle'] = _V2XOBSTACLE
DESCRIPTOR.message_types_by_name['V2XObstacles'] = _V2XOBSTACLES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Point = _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
  'DESCRIPTOR' : _POINT,
  '__module__' : 'modules.v2x.proto.v2x_obstacles_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Point)
  })
_sym_db.RegisterMessage(Point)

MiniAreaMap = _reflection.GeneratedProtocolMessageType('MiniAreaMap', (_message.Message,), {
  'DESCRIPTOR' : _MINIAREAMAP,
  '__module__' : 'modules.v2x.proto.v2x_obstacles_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.MiniAreaMap)
  })
_sym_db.RegisterMessage(MiniAreaMap)

AbnormalInformation = _reflection.GeneratedProtocolMessageType('AbnormalInformation', (_message.Message,), {
  'DESCRIPTOR' : _ABNORMALINFORMATION,
  '__module__' : 'modules.v2x.proto.v2x_obstacles_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.AbnormalInformation)
  })
_sym_db.RegisterMessage(AbnormalInformation)

V2XInformation = _reflection.GeneratedProtocolMessageType('V2XInformation', (_message.Message,), {
  'DESCRIPTOR' : _V2XINFORMATION,
  '__module__' : 'modules.v2x.proto.v2x_obstacles_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.V2XInformation)
  })
_sym_db.RegisterMessage(V2XInformation)

V2XObstacle = _reflection.GeneratedProtocolMessageType('V2XObstacle', (_message.Message,), {
  'DESCRIPTOR' : _V2XOBSTACLE,
  '__module__' : 'modules.v2x.proto.v2x_obstacles_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.V2XObstacle)
  })
_sym_db.RegisterMessage(V2XObstacle)

V2XObstacles = _reflection.GeneratedProtocolMessageType('V2XObstacles', (_message.Message,), {
  'DESCRIPTOR' : _V2XOBSTACLES,
  '__module__' : 'modules.v2x.proto.v2x_obstacles_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.V2XObstacles)
  })
_sym_db.RegisterMessage(V2XObstacles)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/gnss/proto/config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/gnss/proto/config.proto',
  package='apollo.drivers.gnss.config',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'modules/drivers/gnss/proto/config.proto\x12\x1a\x61pollo.drivers.gnss.config\"\xd1\x05\n\x06Stream\x12\x39\n\x06\x66ormat\x18\x01 \x01(\x0e\x32).apollo.drivers.gnss.config.Stream.Format\x12;\n\x06serial\x18\x02 \x01(\x0b\x32).apollo.drivers.gnss.config.Stream.SerialH\x00\x12\x35\n\x03tcp\x18\x03 \x01(\x0b\x32&.apollo.drivers.gnss.config.Stream.TcpH\x00\x12\x35\n\x03udp\x18\x04 \x01(\x0b\x32&.apollo.drivers.gnss.config.Stream.UdpH\x00\x12\x39\n\x05ntrip\x18\x05 \x01(\x0b\x32(.apollo.drivers.gnss.config.Stream.NtripH\x00\x12\x15\n\rpush_location\x18\x06 \x01(\x08\x1a\x31\n\x06Serial\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\x0c\x12\x17\n\tbaud_rate\x18\x02 \x01(\x05:\x04\x39\x36\x30\x30\x1a*\n\x03Tcp\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x12\n\x04port\x18\x02 \x01(\x05:\x04\x33\x30\x30\x31\x1a*\n\x03Udp\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x12\n\x04port\x18\x02 \x01(\x05:\x04\x33\x30\x30\x31\x1ax\n\x05Ntrip\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x12\n\x04port\x18\x02 \x01(\x05:\x04\x32\x31\x30\x31\x12\x13\n\x0bmount_point\x18\x03 \x01(\x0c\x12\x0c\n\x04user\x18\x04 \x01(\x0c\x12\x10\n\x08password\x18\x05 \x01(\x0c\x12\x15\n\ttimeout_s\x18\x06 \x01(\r:\x02\x33\x30\"\x81\x01\n\x06\x46ormat\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NMEA\x10\x01\x12\x0b\n\x07RTCM_V2\x10\x02\x12\x0b\n\x07RTCM_V3\x10\x03\x12\x10\n\x0cNOVATEL_TEXT\x10\n\x12\x12\n\x0eNOVATEL_BINARY\x10\x0b\x12\x0e\n\nUBLOX_TEXT\x10\x14\x12\x10\n\x0cUBLOX_BINARY\x10\x15\x42\x06\n\x04type\"+\n\rNovatelConfig\x12\x1a\n\x0fimu_orientation\x18\x01 \x01(\x05:\x01\x35\"\r\n\x0bUbloxConfig\"U\n\x02TF\x12\x17\n\x08\x66rame_id\x18\x01 \x01(\t:\x05world\x12\x1f\n\x0e\x63hild_frame_id\x18\x02 \x01(\t:\x07novatel\x12\x15\n\x06\x65nable\x18\x03 \x01(\x08:\x05\x66\x61lse\"\xe1\x05\n\x06\x43onfig\x12\x30\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\".apollo.drivers.gnss.config.Stream\x12\x33\n\x07\x63ommand\x18\x02 \x01(\x0b\x32\".apollo.drivers.gnss.config.Stream\x12\x34\n\x08rtk_from\x18\x03 \x01(\x0b\x32\".apollo.drivers.gnss.config.Stream\x12\x32\n\x06rtk_to\x18\x04 \x01(\x0b\x32\".apollo.drivers.gnss.config.Stream\x12\x16\n\x0elogin_commands\x18\x05 \x03(\x0c\x12\x17\n\x0flogout_commands\x18\x06 \x03(\x0c\x12\x43\n\x0enovatel_config\x18\x07 \x01(\x0b\x32).apollo.drivers.gnss.config.NovatelConfigH\x00\x12?\n\x0cublox_config\x18\x08 \x01(\x0b\x32\'.apollo.drivers.gnss.config.UbloxConfigH\x00\x12M\n\x11rtk_solution_type\x18\t \x01(\x0e\x32\x32.apollo.drivers.gnss.config.Config.RtkSolutionType\x12\x35\n\x08imu_type\x18\n \x01(\x0e\x32#.apollo.drivers.gnss.config.ImuType\x12\x12\n\nproj4_text\x18\x0b \x01(\t\x12*\n\x02tf\x18\x0c \x01(\x0b\x32\x1e.apollo.drivers.gnss.config.TF\x12\x18\n\x10wheel_parameters\x18\r \x01(\t\x12\x15\n\rgpsbin_folder\x18\x0e \x01(\t\"G\n\x0fRtkSolutionType\x12\x19\n\x15RTK_RECEIVER_SOLUTION\x10\x01\x12\x19\n\x15RTK_SOFTWARE_SOLUTION\x10\x02\x42\x0f\n\rdevice_config*\xa6\x01\n\x07ImuType\x12\r\n\tIMAR_FSAS\x10\r\x12\x0b\n\x07ISA100C\x10\x1a\x12\r\n\tADIS16488\x10\x1f\x12\x0b\n\x07STIM300\x10 \x12\n\n\x06ISA100\x10\"\x12\x10\n\x0cISA100_400HZ\x10&\x12\x11\n\rISA100C_400HZ\x10\'\x12\x0e\n\nCPT_XW5651\x10(\x12\t\n\x05G320N\x10)\x12\t\n\x05UM442\x10*\x12\x0c\n\x08IAM20680\x10\x39'
)

_IMUTYPE = _descriptor.EnumDescriptor(
  name='ImuType',
  full_name='apollo.drivers.gnss.config.ImuType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMAR_FSAS', index=0, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ISA100C', index=1, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADIS16488', index=2, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STIM300', index=3, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ISA100', index=4, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ISA100_400HZ', index=5, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ISA100C_400HZ', index=6, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CPT_XW5651', index=7, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='G320N', index=8, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UM442', index=9, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IAM20680', index=10, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1683,
  serialized_end=1849,
)
_sym_db.RegisterEnumDescriptor(_IMUTYPE)

ImuType = enum_type_wrapper.EnumTypeWrapper(_IMUTYPE)
IMAR_FSAS = 13
ISA100C = 26
ADIS16488 = 31
STIM300 = 32
ISA100 = 34
ISA100_400HZ = 38
ISA100C_400HZ = 39
CPT_XW5651 = 40
G320N = 41
UM442 = 42
IAM20680 = 57


_STREAM_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='apollo.drivers.gnss.config.Stream.Format',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NMEA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTCM_V2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTCM_V3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOVATEL_TEXT', index=4, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOVATEL_BINARY', index=5, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UBLOX_TEXT', index=6, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UBLOX_BINARY', index=7, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=656,
  serialized_end=785,
)
_sym_db.RegisterEnumDescriptor(_STREAM_FORMAT)

_CONFIG_RTKSOLUTIONTYPE = _descriptor.EnumDescriptor(
  name='RtkSolutionType',
  full_name='apollo.drivers.gnss.config.Config.RtkSolutionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RTK_RECEIVER_SOLUTION', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTK_SOFTWARE_SOLUTION', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1592,
  serialized_end=1663,
)
_sym_db.RegisterEnumDescriptor(_CONFIG_RTKSOLUTIONTYPE)


_STREAM_SERIAL = _descriptor.Descriptor(
  name='Serial',
  full_name='apollo.drivers.gnss.config.Stream.Serial',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='apollo.drivers.gnss.config.Stream.Serial.device', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baud_rate', full_name='apollo.drivers.gnss.config.Stream.Serial.baud_rate', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=9600,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=443,
)

_STREAM_TCP = _descriptor.Descriptor(
  name='Tcp',
  full_name='apollo.drivers.gnss.config.Stream.Tcp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='apollo.drivers.gnss.config.Stream.Tcp.address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='apollo.drivers.gnss.config.Stream.Tcp.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=3001,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=487,
)

_STREAM_UDP = _descriptor.Descriptor(
  name='Udp',
  full_name='apollo.drivers.gnss.config.Stream.Udp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='apollo.drivers.gnss.config.Stream.Udp.address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='apollo.drivers.gnss.config.Stream.Udp.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=3001,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=531,
)

_STREAM_NTRIP = _descriptor.Descriptor(
  name='Ntrip',
  full_name='apollo.drivers.gnss.config.Stream.Ntrip',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='apollo.drivers.gnss.config.Stream.Ntrip.address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='apollo.drivers.gnss.config.Stream.Ntrip.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2101,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mount_point', full_name='apollo.drivers.gnss.config.Stream.Ntrip.mount_point', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='apollo.drivers.gnss.config.Stream.Ntrip.user', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='apollo.drivers.gnss.config.Stream.Ntrip.password', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_s', full_name='apollo.drivers.gnss.config.Stream.Ntrip.timeout_s', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=30,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=653,
)

_STREAM = _descriptor.Descriptor(
  name='Stream',
  full_name='apollo.drivers.gnss.config.Stream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='apollo.drivers.gnss.config.Stream.format', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial', full_name='apollo.drivers.gnss.config.Stream.serial', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp', full_name='apollo.drivers.gnss.config.Stream.tcp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='udp', full_name='apollo.drivers.gnss.config.Stream.udp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ntrip', full_name='apollo.drivers.gnss.config.Stream.ntrip', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='push_location', full_name='apollo.drivers.gnss.config.Stream.push_location', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAM_SERIAL, _STREAM_TCP, _STREAM_UDP, _STREAM_NTRIP, ],
  enum_types=[
    _STREAM_FORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='apollo.drivers.gnss.config.Stream.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=72,
  serialized_end=793,
)


_NOVATELCONFIG = _descriptor.Descriptor(
  name='NovatelConfig',
  full_name='apollo.drivers.gnss.config.NovatelConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='imu_orientation', full_name='apollo.drivers.gnss.config.NovatelConfig.imu_orientation', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=5,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=795,
  serialized_end=838,
)


_UBLOXCONFIG = _descriptor.Descriptor(
  name='UbloxConfig',
  full_name='apollo.drivers.gnss.config.UbloxConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=840,
  serialized_end=853,
)


_TF = _descriptor.Descriptor(
  name='TF',
  full_name='apollo.drivers.gnss.config.TF',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.gnss.config.TF.frame_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"world".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_frame_id', full_name='apollo.drivers.gnss.config.TF.child_frame_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"novatel".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.drivers.gnss.config.TF.enable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=940,
)


_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='apollo.drivers.gnss.config.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='apollo.drivers.gnss.config.Config.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='apollo.drivers.gnss.config.Config.command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtk_from', full_name='apollo.drivers.gnss.config.Config.rtk_from', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtk_to', full_name='apollo.drivers.gnss.config.Config.rtk_to', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='login_commands', full_name='apollo.drivers.gnss.config.Config.login_commands', index=4,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logout_commands', full_name='apollo.drivers.gnss.config.Config.logout_commands', index=5,
      number=6, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='novatel_config', full_name='apollo.drivers.gnss.config.Config.novatel_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ublox_config', full_name='apollo.drivers.gnss.config.Config.ublox_config', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtk_solution_type', full_name='apollo.drivers.gnss.config.Config.rtk_solution_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imu_type', full_name='apollo.drivers.gnss.config.Config.imu_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=13,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proj4_text', full_name='apollo.drivers.gnss.config.Config.proj4_text', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tf', full_name='apollo.drivers.gnss.config.Config.tf', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_parameters', full_name='apollo.drivers.gnss.config.Config.wheel_parameters', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpsbin_folder', full_name='apollo.drivers.gnss.config.Config.gpsbin_folder', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONFIG_RTKSOLUTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='device_config', full_name='apollo.drivers.gnss.config.Config.device_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=943,
  serialized_end=1680,
)

_STREAM_SERIAL.containing_type = _STREAM
_STREAM_TCP.containing_type = _STREAM
_STREAM_UDP.containing_type = _STREAM
_STREAM_NTRIP.containing_type = _STREAM
_STREAM.fields_by_name['format'].enum_type = _STREAM_FORMAT
_STREAM.fields_by_name['serial'].message_type = _STREAM_SERIAL
_STREAM.fields_by_name['tcp'].message_type = _STREAM_TCP
_STREAM.fields_by_name['udp'].message_type = _STREAM_UDP
_STREAM.fields_by_name['ntrip'].message_type = _STREAM_NTRIP
_STREAM_FORMAT.containing_type = _STREAM
_STREAM.oneofs_by_name['type'].fields.append(
  _STREAM.fields_by_name['serial'])
_STREAM.fields_by_name['serial'].containing_oneof = _STREAM.oneofs_by_name['type']
_STREAM.oneofs_by_name['type'].fields.append(
  _STREAM.fields_by_name['tcp'])
_STREAM.fields_by_name['tcp'].containing_oneof = _STREAM.oneofs_by_name['type']
_STREAM.oneofs_by_name['type'].fields.append(
  _STREAM.fields_by_name['udp'])
_STREAM.fields_by_name['udp'].containing_oneof = _STREAM.oneofs_by_name['type']
_STREAM.oneofs_by_name['type'].fields.append(
  _STREAM.fields_by_name['ntrip'])
_STREAM.fields_by_name['ntrip'].containing_oneof = _STREAM.oneofs_by_name['type']
_CONFIG.fields_by_name['data'].message_type = _STREAM
_CONFIG.fields_by_name['command'].message_type = _STREAM
_CONFIG.fields_by_name['rtk_from'].message_type = _STREAM
_CONFIG.fields_by_name['rtk_to'].message_type = _STREAM
_CONFIG.fields_by_name['novatel_config'].message_type = _NOVATELCONFIG
_CONFIG.fields_by_name['ublox_config'].message_type = _UBLOXCONFIG
_CONFIG.fields_by_name['rtk_solution_type'].enum_type = _CONFIG_RTKSOLUTIONTYPE
_CONFIG.fields_by_name['imu_type'].enum_type = _IMUTYPE
_CONFIG.fields_by_name['tf'].message_type = _TF
_CONFIG_RTKSOLUTIONTYPE.containing_type = _CONFIG
_CONFIG.oneofs_by_name['device_config'].fields.append(
  _CONFIG.fields_by_name['novatel_config'])
_CONFIG.fields_by_name['novatel_config'].containing_oneof = _CONFIG.oneofs_by_name['device_config']
_CONFIG.oneofs_by_name['device_config'].fields.append(
  _CONFIG.fields_by_name['ublox_config'])
_CONFIG.fields_by_name['ublox_config'].containing_oneof = _CONFIG.oneofs_by_name['device_config']
DESCRIPTOR.message_types_by_name['Stream'] = _STREAM
DESCRIPTOR.message_types_by_name['NovatelConfig'] = _NOVATELCONFIG
DESCRIPTOR.message_types_by_name['UbloxConfig'] = _UBLOXCONFIG
DESCRIPTOR.message_types_by_name['TF'] = _TF
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.enum_types_by_name['ImuType'] = _IMUTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Stream = _reflection.GeneratedProtocolMessageType('Stream', (_message.Message,), {

  'Serial' : _reflection.GeneratedProtocolMessageType('Serial', (_message.Message,), {
    'DESCRIPTOR' : _STREAM_SERIAL,
    '__module__' : 'modules.drivers.gnss.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.config.Stream.Serial)
    })
  ,

  'Tcp' : _reflection.GeneratedProtocolMessageType('Tcp', (_message.Message,), {
    'DESCRIPTOR' : _STREAM_TCP,
    '__module__' : 'modules.drivers.gnss.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.config.Stream.Tcp)
    })
  ,

  'Udp' : _reflection.GeneratedProtocolMessageType('Udp', (_message.Message,), {
    'DESCRIPTOR' : _STREAM_UDP,
    '__module__' : 'modules.drivers.gnss.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.config.Stream.Udp)
    })
  ,

  'Ntrip' : _reflection.GeneratedProtocolMessageType('Ntrip', (_message.Message,), {
    'DESCRIPTOR' : _STREAM_NTRIP,
    '__module__' : 'modules.drivers.gnss.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.config.Stream.Ntrip)
    })
  ,
  'DESCRIPTOR' : _STREAM,
  '__module__' : 'modules.drivers.gnss.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.config.Stream)
  })
_sym_db.RegisterMessage(Stream)
_sym_db.RegisterMessage(Stream.Serial)
_sym_db.RegisterMessage(Stream.Tcp)
_sym_db.RegisterMessage(Stream.Udp)
_sym_db.RegisterMessage(Stream.Ntrip)

NovatelConfig = _reflection.GeneratedProtocolMessageType('NovatelConfig', (_message.Message,), {
  'DESCRIPTOR' : _NOVATELCONFIG,
  '__module__' : 'modules.drivers.gnss.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.config.NovatelConfig)
  })
_sym_db.RegisterMessage(NovatelConfig)

UbloxConfig = _reflection.GeneratedProtocolMessageType('UbloxConfig', (_message.Message,), {
  'DESCRIPTOR' : _UBLOXCONFIG,
  '__module__' : 'modules.drivers.gnss.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.config.UbloxConfig)
  })
_sym_db.RegisterMessage(UbloxConfig)

TF = _reflection.GeneratedProtocolMessageType('TF', (_message.Message,), {
  'DESCRIPTOR' : _TF,
  '__module__' : 'modules.drivers.gnss.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.config.TF)
  })
_sym_db.RegisterMessage(TF)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'modules.drivers.gnss.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.config.Config)
  })
_sym_db.RegisterMessage(Config)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/localization/proto/measure.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/localization/proto/measure.proto',
  package='apollo.localization',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(modules/localization/proto/measure.proto\x12\x13\x61pollo.localization\x1a!modules/common/proto/header.proto\x1a#modules/common/proto/geometry.proto\"\xd6\x04\n\x0cIntegMeasure\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x43\n\x0cmeasure_type\x18\x02 \x01(\x0e\x32-.apollo.localization.IntegMeasure.MeasureType\x12?\n\nframe_type\x18\x03 \x01(\x0e\x32+.apollo.localization.IntegMeasure.FrameType\x12(\n\x08position\x18\x04 \x01(\x0b\x32\x16.apollo.common.Point3D\x12(\n\x08velocity\x18\x05 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x0b\n\x03yaw\x18\x06 \x01(\x01\x12\x0f\n\x07zone_id\x18\x07 \x01(\x05\x12\x18\n\x10is_have_variance\x18\x08 \x01(\x08\x12\x1e\n\x16is_gnss_double_antenna\x18\t \x01(\x08\x12\x19\n\rmeasure_covar\x18\n \x03(\x01\x42\x02\x10\x01\"\x9a\x01\n\x0bMeasureType\x12\x11\n\rGNSS_POS_ONLY\x10\x00\x12\x10\n\x0cGNSS_POS_VEL\x10\x01\x12\x0f\n\x0bGNSS_POS_XY\x10\x02\x12\x11\n\rGNSS_VEL_ONLY\x10\x03\x12\x13\n\x0fPOINT_CLOUD_POS\x10\x04\x12\x15\n\x11ODOMETER_VEL_ONLY\x10\x05\x12\x16\n\x12VEHICLE_CONSTRAINT\x10\x06\"5\n\tFrameType\x12\x07\n\x03\x45NU\x10\x00\x12\x08\n\x04\x45\x43\x45\x46\x10\x01\x12\x07\n\x03UTM\x10\x02\x12\x0c\n\x08ODOMETER\x10\x03'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])



_INTEGMEASURE_MEASURETYPE = _descriptor.EnumDescriptor(
  name='MeasureType',
  full_name='apollo.localization.IntegMeasure.MeasureType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GNSS_POS_ONLY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GNSS_POS_VEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GNSS_POS_XY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GNSS_VEL_ONLY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POINT_CLOUD_POS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ODOMETER_VEL_ONLY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLE_CONSTRAINT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=527,
  serialized_end=681,
)
_sym_db.RegisterEnumDescriptor(_INTEGMEASURE_MEASURETYPE)

_INTEGMEASURE_FRAMETYPE = _descriptor.EnumDescriptor(
  name='FrameType',
  full_name='apollo.localization.IntegMeasure.FrameType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENU', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECEF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UTM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ODOMETER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=683,
  serialized_end=736,
)
_sym_db.RegisterEnumDescriptor(_INTEGMEASURE_FRAMETYPE)


_INTEGMEASURE = _descriptor.Descriptor(
  name='IntegMeasure',
  full_name='apollo.localization.IntegMeasure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.localization.IntegMeasure.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measure_type', full_name='apollo.localization.IntegMeasure.measure_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_type', full_name='apollo.localization.IntegMeasure.frame_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.localization.IntegMeasure.position', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='apollo.localization.IntegMeasure.velocity', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw', full_name='apollo.localization.IntegMeasure.yaw', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='apollo.localization.IntegMeasure.zone_id', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_have_variance', full_name='apollo.localization.IntegMeasure.is_have_variance', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_gnss_double_antenna', full_name='apollo.localization.IntegMeasure.is_gnss_double_antenna', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measure_covar', full_name='apollo.localization.IntegMeasure.measure_covar', index=9,
      number=10, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INTEGMEASURE_MEASURETYPE,
    _INTEGMEASURE_FRAMETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=736,
)

_INTEGMEASURE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_INTEGMEASURE.fields_by_name['measure_type'].enum_type = _INTEGMEASURE_MEASURETYPE
_INTEGMEASURE.fields_by_name['frame_type'].enum_type = _INTEGMEASURE_FRAMETYPE
_INTEGMEASURE.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_INTEGMEASURE.fields_by_name['velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_INTEGMEASURE_MEASURETYPE.containing_type = _INTEGMEASURE
_INTEGMEASURE_FRAMETYPE.containing_type = _INTEGMEASURE
DESCRIPTOR.message_types_by_name['IntegMeasure'] = _INTEGMEASURE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IntegMeasure = _reflection.GeneratedProtocolMessageType('IntegMeasure', (_message.Message,), {
  'DESCRIPTOR' : _INTEGMEASURE,
  '__module__' : 'modules.localization.proto.measure_pb2'
  # @@protoc_insertion_point(class_scope:apollo.localization.IntegMeasure)
  })
_sym_db.RegisterMessage(IntegMeasure)


_INTEGMEASURE.fields_by_name['measure_covar']._options = None
# @@protoc_insertion_point(module_scope)
